#!/usr/bin/python
#
# Simple app for reading bytes.
#

import serial
import time
import sys
import signal
import stat,os
from optparse import OptionParser

global exit_loop
exit_loop = False



def handler(signum, frame):
    show_count()

def show_count():
    global count , failed
    print "Summary: count=%d , failed=%d\n" % ( count, failed )


signal.signal(signal.SIGHUP, handler)



usage  = """usage: %prog -p PORT  [ options ]
     [-b | --baud ] BAUDRATE 
     [-t | --timeout] TIMEOUT
"""
parser = OptionParser(usage,add_help_option=True)
parser.add_option("-p","--serial", dest="port",help="Required port")
parser.add_option("-b","--baud", type="int",dest="baud" , default=9600)
parser.add_option("-t","--timeout", type="int", dest="timeout", default=1 )

(options,args) = parser.parse_args()
if options.port == None:
    parser.error( "Please specify a port, -p PORT" )

# First if part only for local testing
#
if stat.S_ISFIFO(os.stat(options.port).st_mode):
    ser = file(options.port,"r")
else:
    ser = serial.Serial(port=options.port, timeout=options.timeout, baudrate=options.baud )
    ser.setDTR(1)


count = 0
failed = 0
prevbyte = -1
startval = 1
while not exit_loop:
    try:
        data = ser.read(256)
        count += len(data)
        if len(data) > 0:
            if prevbyte == -1:
                prevbyte = data[0]
                startval = 1
            else:
                startval = 0
            for i in range(startval,len(data)):
                byte = data[i]
                if ((ord(prevbyte) + 1 ) % 256) != ord(byte):
                    print "Error: Next byte is incorrect, prev=%s,next=%s,exp=%s" % ( prevbyte, byte,chr( (ord(prevbyte) + 1) %256 ))
                    failed += 1
                prevbyte = byte

    except KeyboardInterrupt:
        print "Ending\n"
        exit_loop = True
    except serial.serialutil.SerialException:
        print "Continuing"
    except Exception:
        print ""
    finally:
        next

print "Summary: count=%d , failed=%d\n" % ( count, failed )
